**********************************************
:mod:`mopidy.mixers.osa` -- Osa mixer for OS X
**********************************************

.. inheritance-diagram:: mopidy.mixers.osa

.. automodule:: mopidy.mixers.osa
    :synopsis: Osa mixer for OS X
    :members:
